@@ -13,8 +13,10 @@ class ValidatorError(Enum):
 
 
 class Validator:
+	_exact_keys = False
+
 	def __init__(self, data: dict | list | None = None, exact_keys: bool = False):
-		self._exact_keys = exact_keys
+		self.__class__._exact_keys = exact_keys
 		self._schema = {}
 		for key, val in self.__class__.__dict__.items():
 			if key[0] == "_":
@@ -33,7 +35,7 @@ class Validator:
 		return ""
 
 	def __call__(self, data, *args, **kwargs) -> tuple[bool, Any, str]:
-		if self._exact_keys:
+		if self.__class__._exact_keys:
 			for key in data:
 				if key not in self._schema.keys():
 					return False, ValidatorError.INVALID_SCHEMA, ""
